@@ -42,7 +42,7 @@
 #define _I2C_H
 
 /* --- General options ------------------------------------------------	*/
-#define I2C_MAJOR	63			/* Device major number	*/
+#define I2C_MAJOR	89			/* Device major number	*/
 
 /* --- Select one of the following: -----------------------------------	*/
 /*
@@ -58,7 +58,7 @@
 
 #define I2C_MAGIC	0x090203/* magic number for the struct		*/
 
-/* ----- IOCTLs */
+/* ----- IOCTL's - note that some HW may support some, others not!	*/
 				/* -> bit-adapter specific ioctls	*/
 #define I2C_TIMEOUT	0x0701	/* set timeout - call with int 		*/
 #define I2C_UDELAY	0x0702  /* set delay in microsecs between each  */
@@ -78,6 +78,7 @@
 #define I2C_CLEAR	0x07fe	/* when lost, use to clear stale info	*/
 #define I2C_V_SLOW	0x07ff  /* set jiffies delay call with int 	*/
 
+#define I2C_INTR	0x0707	/* Pass interrupt number (*lp*)		*/
 
 /* This is strictly experimental and currently not used (but soon;)	*/
 #ifdef VT1500
@@ -93,8 +94,13 @@ struct i2c_struct {
 	int timeout;
 	int udelay,mdelay;	/* usec & msec delay times 		*/
 	int retries;
-	int veryslow;	/* used by SLO_IO - only for debugging 		*/
-			/* this might go away if not needed...		*/
+	int veryslow;		/* used by SLO_IO - only for debugging 	*/
+				/* this might go away if not needed...	*/
+	int irq;		/* number of int, or 0 if none		*/
+	
+	struct wait_queue *wait_q;/* for interrupt enabled HW		*/
+	char *buffer;		/* int. buffer for transfer		*/
+	void *minor_data;	/* low-level data, for ease of reference*/
 };
 
 extern struct i2c_struct i2c_table[];
@@ -124,6 +130,18 @@ extern struct i2c_struct i2c_table[];
 
 #define I2C_HW_ADAPS	0x10	/* number of different hw implements per*/
 				/* algorithm layer module		*/
-#define I2C_HW_MASK	0x0f	/* space for indiv. hw implments	*/
+#define I2C_HW_MASK	0x0f	/* space for indiv. hw implmentations	*/
+
+/* --- Bit algorithm adapters 						*/
+#define HW_B_LP		0x00	/* Parallel port Philips style adapter	*/
+#define HW_B_LPC	0x01	/* Parallel port, over control reg.	*/
+#define HW_B_SER	0x02	/* Serial line interface		*/
+#define HW_B_ELV	0x03	/* ELV Card				*/
+#define HW_B_VELLE	0x04	/* Vellemann K8000			*/
+
+/* --- PCF 8584 based algorithms					*/
+#define HW_P_LP		0x00	/* Parallel port interface		*/
+#define HW_P_ISA	0x01	/* generic ISA Bus inteface card	*/
+#define HW_P_ELEK	0x02	/* Elektor ISA Bus inteface card	*/
 
 #endif
