@@ -99,18 +99,15 @@ int I2CGadgetCmd(ClientData data, Tcl_Interp *interp,int argc, char **argv){
                 n=0;
 		if (TCL_OK != Tcl_GetInt(interp,argv[2],&n))
 			return TCL_ERROR;
-		buf=malloc(n*sizeof(char));
-		i=read (ip->file,buf,n);
+		buf = malloc(n*sizeof(char));
+		i = read (ip->file,buf,n);
                 if (i==-1){ 
                 	interp->result=strerror(errno);
                 	return TCL_ERROR;
                 }
- 		for (i=0;i<n;i++){
+ 		for (i=0;i<n;i++) {
 			sprintf(num,"%d",buf[i]);
-			Tcl_AppendResult(interp,num,(char*)NULL);
-			if (i<n-1){
-				Tcl_AppendResult(interp," ",(char*)NULL);
-			}
+			Tcl_AppendElement(interp,num);
 		}
 		free(buf);
 	} else if (argc==2){
@@ -165,20 +162,42 @@ int I2CCmd(ClientData clientData, Tcl_Interp *interp,
 			int argc, char**argv)
 {
     I2C *inew, *ip =(I2C*)clientData;
-
-    if (argc != 2) {
+    char *path,*dev = I2C_DEVICE;	// hardcoded default
+    
+    if (argc < 2) {
         Tcl_AppendResult(interp, "wrong # args:  should be \"",
-                argv[0], " pathName \"", (char *) NULL);
+                argv[0], " [-device </dev/i2c*] pathName \"", (char *) NULL);
         return TCL_ERROR;
     }
+    path = argv[1];
+    if  (strncmp("-device",argv[1],strlen(argv[1]))==0) {
+    	if (argc < 4) {
+	    interp->result="device needs more arguments (missing device/path)";
+	    return TCL_ERROR;
+    	}
+	dev = argv[2];
+	path = argv[3];
+    }
     inew = (I2C *) ckalloc(sizeof(I2C));
+    if (inew==NULL) {
+	interp->result="out of memory";
+	return TCL_ERROR;
+    }
+
+
+    inew->file=open(dev,O_RDWR);
+    if (inew->file<=0) {
+	interp->result="could not open device file ";
+	return TCL_ERROR;
+    }
+
     inew->udelay=ip->udelay;
     inew->mdelay=ip->mdelay;
-    inew->file=ip->file;
     inew->buf=(char*)malloc(128);
-    inew->buflen=(inew->buf==NULL)?0:128; /* if we haven't got memory we'll try later */
-    Tcl_CreateCommand(interp,argv[1], I2CGadgetCmd,
-                (ClientData) inew, I2CDestroy);
+    inew->buflen=(inew->buf==NULL) ? 0:128; 
+    	/* if we haven't got memory we'll try later */
+    Tcl_CreateCommand(interp,path, I2CGadgetCmd,
+	(ClientData) inew, I2CDestroy);
     return TCL_OK;
 }
 
@@ -192,7 +211,7 @@ int I2CCmd(ClientData clientData, Tcl_Interp *interp,
 void I2CDestroy(ClientData clientData) {
     I2C *ip = (I2C *) clientData;
     close(ip->file);
-	free(ip->buf);
+    free(ip->buf);
     ckfree((char *) ip);
 }
 
@@ -209,8 +228,8 @@ void I2CInit(Tcl_Interp *interp){
     ip=(I2C*)ckalloc(sizeof(I2C));
     if (!ip)
     	printf("Out of memory!!\n");
-    ip->file=open(I2C_DEVICE,O_RDWR);
-    if (ip->file==-1){
+//    ip->file=open(I2C_DEVICE,O_RDWR);
+    if ( ip->file == -1 ) {
     	printf("i2c_init: error opening device: %s\n",strerror(errno));
     }
     ip->udelay=ip->mdelay=0;
