@@ -23,6 +23,11 @@ proc initDisplay {{b .display}} {
 	wm title $b "Videotext Display"
 	set vtex(display) 1
 
+	# debugging:
+	menu $b.deb
+        $b.deb add command -label "..." -command {}
+	$b.deb add command -label "+++" -command {} 
+	$b.deb add command -label "---" -command {}
 
 	set x 0
 	set y 0
@@ -39,7 +44,7 @@ proc initDisplay {{b .display}} {
 			set x [ expr $x + 18 ]
 
 			# debugging ...
-			
+
 			bind $b.$i.$j <Any-ButtonPress-1> "
 				$b.deb entryconf 0 -label \"%W\"
 				$b.deb entryconf 1 -label \"\[%W conf -text\] \"
@@ -52,11 +57,6 @@ proc initDisplay {{b .display}} {
 		set x 0
 		set y [ expr $y + 18 ]
 	} 
-	# now some fancy debugging features:
-	menu $b.deb
-    $b.deb add command -label "..." -command {}
-	$b.deb add command -label "+++" -command {} 
-	$b.deb add command -label "---" -command {}
 }
 
 proc initMenu {{m .menu}} {
@@ -366,7 +366,7 @@ proc updStatus {} {
         $b.3.mt conf -text "[expr [lindex $pag 3]&16!=0]"
         $b.3.mu conf -text "[expr [lindex $pag 2]&16!=0]"
 
-#		$b.4 conf -text "[expr [lindex $pag 3]&8!=0][expr [lindex $pag 5]&4!=0][expr [lindex $pag 5]&8!=0][expr [lindex $pag 6]&1!=0][expr [lindex $pag 6]&2!=0][expr [lindex $pag 6]&4!=0][expr [lindex $pag 6]&8!=0]"
+		$b.4 conf -label "[expr [lindex $pag 3]&8!=0][expr [lindex $pag 5]&4!=0][expr [lindex $pag 5]&8!=0][expr [lindex $pag 6]&1!=0][expr [lindex $pag 6]&2!=0][expr [lindex $pag 6]&4!=0][expr [lindex $pag 6]&8!=0]"
 
 		set lng [expr ([lindex $pag 7]&8)/8 + ([lindex $pag 7]&4)/2+([lindex $pag 7]&2)*2]
 		$b.4.2.1 conf -text "$lang($lng)"
